@@ -33,6 +33,7 @@
 #include <bonobo/bonobo-macros.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
+#include <eel/eel-vfs-extensions.h>
 
 #include "eog-image-view.h"
 #include "eog-scroll-view.h"
@@ -428,6 +429,8 @@ eog_image_view_create_ui (EogImageView *image_view)
 	/* Set up the UI from XML file. */
         bonobo_ui_util_set_ui (priv->uic, DATADIR,
 			       "eog-image-view-ui.xml", "EogImageView", NULL);
+	bonobo_ui_component_set_prop (priv->uic, "/menu/Edit/Eog EditPreferences Separator",
+				      "hidden", "0", NULL);
 	bonobo_ui_component_add_verb_list_with_data (priv->uic, eog_verbs,
 						     image_view);
 
@@ -648,8 +651,6 @@ eog_image_view_finalize (GObject *object)
 	g_free (priv);
 	image_view->priv = NULL;
 
-	g_message ("EogImageView finalize");
-
 	BONOBO_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
@@ -1029,8 +1030,7 @@ load_uri_cb (BonoboPersistFile *pf, const CORBA_char *text_uri,
 	EogImageView *view;
 	EogImageViewPrivate *priv;
 	EogImage *image;
-
-	g_print ("load uri: %s\n", text_uri);
+	char *valid_uri;
 
 	view = EOG_IMAGE_VIEW (closure);
 	priv = view->priv;
@@ -1046,7 +1046,9 @@ load_uri_cb (BonoboPersistFile *pf, const CORBA_char *text_uri,
 		priv->image = NULL;
 	}
 
-	image = eog_image_new (text_uri);
+	valid_uri = eel_make_uri_from_input (text_uri);
+
+	image = eog_image_new (valid_uri);
 	priv->image_signal_id[0] = g_signal_connect (image, "loading_size_prepared", G_CALLBACK (image_size_prepared_cb), view);
 	priv->image_signal_id[1] = g_signal_connect (image, "progress", G_CALLBACK (image_progress_cb), view);
 	priv->image_signal_id[2] = g_signal_connect (image, "image_changed", G_CALLBACK (image_changed_cb), view);
@@ -1055,6 +1057,7 @@ load_uri_cb (BonoboPersistFile *pf, const CORBA_char *text_uri,
 	priv->image = image;
 
 	eog_scroll_view_set_image (EOG_SCROLL_VIEW (priv->widget), image);
+	g_free (valid_uri);
 
 	return 0;
 }
